==> gofigure2_0.8.1.orig.tar.gz: GoFigure2-v0.8.1/Examples/IO/GoDBMeshRowTest.cxx <==
/*=========================================================================
 Authors: The GoFigure Dev. Team.
 at Megason Lab, Systems biology, Harvard Medical school, 2009-11

 Copyright (c) 2009-11, President and Fellows of Harvard College.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice,
 this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
 Neither the name of the  President and Fellows of Harvard College
 nor the names of its contributors may be used to endorse or promote
 products derived from this software without specific prior written
 permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "GoDBMeshRow.h"

int main(int argc, char **argv)
{
  (void)argc;
  (void)argv;

  GoDBMeshRow row;
  std::cout << "std::cout TEST... " << std::endl;
  std::cout << row << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "GetTableName TEST... " << std::endl;
  std::cout << row.GetTableName() << std::endl;
  std::cout << "DONE!" << std::endl;

  std::cout << "GetTableIDName TEST... " << std::endl;
  std::cout << row.GetTableIDName() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "PrintValues TEST... " << std::endl;
  std::cout << row.PrintValues() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "PrintColumnNames TEST... " << std::endl;
  std::cout << row.PrintColumnNames() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "iterator TEST... " << std::endl;
  std::map< std::string, std::string >::iterator it = row.MapBegin();
  while ( it != row.MapEnd() )
    {
    ++it;
    }
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "const iterator TEST... " << std::endl;
  std::map< std::string, std::string >::const_iterator
    c_it = row.ConstMapBegin();

  while ( c_it != row.ConstMapEnd() )
    {
    ++c_it;
    }

  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "erroneous GetMapValue TEST... " << std::endl;
  std::cout << row.GetMapValue("contour") << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "GetMapValue TEST... " << std::endl;
  std::cout << row.GetMapValue("CellTypeID") << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  return EXIT_SUCCESS;
}

==> gofigure2_0.9.0.orig.tar.gz: GoFigure2-v0.9.0/Examples/IO/GoDBMeshRowTest.cxx <==
/*=========================================================================
 Authors: The GoFigure Dev. Team.
 at Megason Lab, Systems biology, Harvard Medical school, 2009-11

 Copyright (c) 2009-11, President and Fellows of Harvard College.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice,
 this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
 Neither the name of the  President and Fellows of Harvard College
 nor the names of its contributors may be used to endorse or promote
 products derived from this software without specific prior written
 permission.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "GoDBMeshRow.h"

int main(int argc, char **argv)
{
  (void)argc;
  (void)argv;

  GoDBMeshRow row;
  std::cout << "std::cout TEST... " << std::endl;
  std::cout << row << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "GetTableName TEST... " << std::endl;
  std::cout << row.GetTableName() << std::endl;
  std::cout << "DONE!" << std::endl;

  std::cout << "GetTableIDName TEST... " << std::endl;
  std::cout << row.GetTableIDName() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "PrintValues TEST... " << std::endl;
  std::cout << row.PrintValues() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "PrintColumnNames TEST... " << std::endl;
  std::cout << row.PrintColumnNames() << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "iterator TEST... " << std::endl;
  GoDBMeshRow::StringMapIterator it = row.MapBegin();
  while ( it != row.MapEnd() )
    {
    ++it;
    }
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "const iterator TEST... " << std::endl;
  GoDBMeshRow::StringMapConstIterator c_it = row.ConstMapBegin();

  while ( c_it != row.ConstMapEnd() )
    {
    ++c_it;
    }

  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "erroneous GetMapValue TEST... " << std::endl;
  std::cout << row.GetMapValue("contour") << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  std::cout << "GetMapValue TEST... " << std::endl;
  std::cout << row.GetMapValue("CellTypeID") << std::endl;
  std::cout << "DONE!" << std::endl;
  std::cout << std::endl;

  return EXIT_SUCCESS;
}
